---
name: Bug report
about: Create a report to help us improve

---

**Prerequisites**

* [ ] Put an X between the brackets on this line if you have done all of the following:
    * Reproduced the problem in a new virtualenv with only neuralprophet installed, directly from github:
      ```shell
      git clone <copied link from github>
      cd neural_prophet
      pip install .
      ```
    * Checked the Answered Questions on the Github Disscussion board: https://github.com/ourownstory/neural_prophet/discussions
      If you have the same question but the Answer does not solve your issue, please continue the conversation there.
    * Checked that your issue isn't already filed: https://github.com/ourownstory/neural_prophet/issues
      If you have the same issue but there is a twist to your situation, please add an explanation there.
    * Considered whether your bug might actually be solveable by getting a question answered: 
      * Please [post a package use question](https://github.com/ourownstory/neural_prophet/discussions/categories/q-a-get-help-using-neuralprophet)
      * Please [post a forecasting best practice question](https://github.com/ourownstory/neural_prophet/discussions/categories/q-a-forecasting-best-practices)
      * Please [post an idea or feedback](https://github.com/ourownstory/neural_prophet/discussions/categories/ideas-feedback)

**Describe the bug**

A clear and concise description of what the bug is.

**To Reproduce**

Steps to reproduce the behavior:
1. With the data '...'
2. Setting the model hyperparameters '....'
3. After running these code lines '....'
4. When using this function '....'
5. See error

**Expected behavior**

A clear and concise description of what you expected to happen.


**What actually happens**

Describe what happens, and how often it happens.

**Screenshots**

If applicable, add screenshots and console printouts to help explain your problem.

**Environement (please complete the following information):**

 - Python environment [e.g. Python 3.8, in standalone venv with no other packages]
 - NeuralProphet version and install method [e.g. 2.7, installed from PYPI with `pip install neuralprophet`]

**Additional context**

Add any other context about the problem here.
